aboutsummaryrefslogtreecommitdiffstats
path: root/tethereal.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2005-08-19 09:29:41 +0000
committerGuy Harris <guy@alum.mit.edu>2005-08-19 09:29:41 +0000
commitb2807e2ab65c7c96b38c4b08b4b491986719378a (patch)
tree76e4a11481ef4c452fdb6528527c87a5b32d6631 /tethereal.c
parent3723032609805d89e3a155d6273833f7febdd899 (diff)
Move the APIs for registering and processing "-z" command-line arguments
and "Statistics" menu items into "stat.h" and "stat.c", to separate them from the core tapping APIs. A tap could conceivably not register as a "-z" command-line argument or "Statistics" menu item, and a stat could conceivably not be implemented as a tap, and dissectors that implement tapping points don't need the UI-related stuff from "stat.h", they just want the tap-related stuff in <epan/tap.h>. svn path=/trunk/; revision=15427
Diffstat (limited to 'tethereal.c')
-rw-r--r--tethereal.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/tethereal.c b/tethereal.c
index ec69777f28..028d85479b 100644
--- a/tethereal.c
+++ b/tethereal.c
@@ -1009,15 +1009,15 @@ main(int argc, char *argv[])
print_hex = TRUE;
break;
case 'z':
/* We won't call the init function for the tap this soon
as it would disallow MATE's fields (which are registered
by the preferences set callback) from being used as
part of a tap filter. Instead, we just add the argument
- to a list of tap arguments. */
- if (!process_tap_cmd_arg(optarg)) {
+ to a list of stat arguments. */
+ if (!process_stat_cmd_arg(optarg)) {
fprintf(stderr,"tethereal: invalid -z argument.\n");
fprintf(stderr," -z argument must be one of :\n");
- list_tap_cmd_args();
+ list_stat_cmd_args();
exit(1);
}
break;
@@ -1196,9 +1196,9 @@ main(int argc, char *argv[])
prefs_apply_all();
/* At this point MATE will have registered its field array so we can
- have a filter with one of MATE's late-registered fields as part
- of the tap's filter. We can now process all the "-z" arguments. */
- start_requested_taps();
+ have a tap filter with one of MATE's late-registered fields as part
+ of the filter. We can now process all the "-z" arguments. */
+ start_requested_stats();
/* disabled protocols as per configuration file */
if (gdp_path == NULL && dp_path == NULL) {
@@ -1009,15 +1009,15 @@ main(int argc, char *argv[])
break;
case 'z':
- /* We won't call the init function for the tap this soon
+ /* We won't call the init function for the stat this soon
as it would disallow MATE's fields (which are registered
by the preferences set callback) from being used as